@@ -18,7 +18,6 @@ class QToolButton;
 class QScrollArea;
 class QLabel;
 class QVBoxLayout;
-class KMoreToolsMenuFactory;
 
 /**
  * @brief Input box for searching files with or without Baloo.
@@ -172,7 +171,6 @@ private:
     DolphinFacetsWidget *m_facetsWidget;
 
     QUrl m_searchPath;
-    QScopedPointer<KMoreToolsMenuFactory> m_menuFactory;
 
     QTimer *m_startSearchTimer;
 };
